/*
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */
package org.example.junit;

import junit.framework.TestCase;

/**
 * Not really a test of Ant but a test that is run by the test of the
 * junit task.  Confused?
 *
 * @since Ant 1.5
 */
public class ThreadedOutput extends TestCase {

    public ThreadedOutput(String s) {
        super(s);
    }

    public void testOutput() throws InterruptedException {
        Thread t = new Thread(() -> System.out.println("foo"));
        t.start();
        t.join();
    }
}
